@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Tester
 #
-# This software is Copyright (c) 2015 by Dominique Dumont.
+# This software is Copyright (c) 2013-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -9,7 +9,7 @@
 #
 package Config::Model::Tester;
 # ABSTRACT: Test framework for Config::Model
-$Config::Model::Tester::VERSION = '2.052';
+$Config::Model::Tester::VERSION = '2.054';
 use warnings;
 use strict;
 use locale;
@@ -32,6 +32,7 @@ use Test::Memory::Cycle ;
 # creating a build dependency loop.
 eval {
     require Config::Model;
+    require Config::Model::Lister;
     require Config::Model::Value;
     require Config::Model::BackendMgr;
 } ;
@@ -45,19 +46,21 @@ require Exporter;
 $File::Copy::Recursive::DirPerms = 0755;
 
 sub setup_test {
-    my ( $model_test, $t_name, $wr_root, $trace, $setup ) = @_;
+    my ( $app_to_test, $t_name, $wr_root, $trace, $setup ) = @_;
 
     # cleanup before tests
     $wr_root->remove_tree();
     $wr_root->mkpath( { mode => 0755 } );
 
+    $conf_dir =~ s!~/!$home_for_test/!;
+
     my $wr_dir    = $wr_root->child('test-' . $t_name);
     my $wr_dir2   = $wr_root->child('test-' . $t_name.'-w');
     my $conf_file ;
     $conf_file = $wr_dir->child($conf_dir,$conf_file_name)
         if $conf_dir and $conf_file_name;
 
-    my $ex_dir = path('t')->child('model_tests.d', "$model_test-examples");
+    my $ex_dir = path('t')->child('model_tests.d', "$app_to_test-examples");
     my $ex_data = $ex_dir->child($t_name);
 
     my @file_list;
@@ -69,26 +72,33 @@ sub setup_test {
                 = ref ($map) eq 'HASH' ? $map->{$^O} // $map->{default}
                 :                        $map;
             if (not defined $destination_str) {
-                die "$model_test $t_name setup error: cannot find destination for test file $file" ;
+                die "$app_to_test $t_name setup error: cannot find destination for test file $file" ;
             }
+            $destination_str =~ s!~/!$home_for_test/!;
             my $destination = $wr_dir->child($destination_str) ;
             $destination->parent->mkpath( { mode => 0755 }) ;
-            my $data = $ex_data->child($file)->slurp() ;
+            my $data_file = $ex_data->child($file);
+            die "cannot find $data_file" unless $data_file->exists;
+            my $data = $data_file->slurp() ;
             $destination->spew( $data );
             @file_list = list_test_files ($wr_dir);
         }
     }
     elsif ( $ex_data->is_dir ) {
         # copy whole dir
-        my $debian_dir = $conf_dir ? $wr_dir->child($conf_dir) : $wr_dir ;
-        $debian_dir->mkpath( { mode => 0755 });
-        say "dircopy ". $ex_data->stringify . '->'. $debian_dir->stringify
+        my $destination_dir = $conf_dir ? $wr_dir->child($conf_dir) : $wr_dir ;
+        $destination_dir->mkpath( { mode => 0755 });
+        say "dircopy ". $ex_data->stringify . '->'. $destination_dir->stringify
             if $trace ;
-        dircopy( $ex_data->stringify, $debian_dir->stringify )
-          || die "dircopy $ex_data -> $debian_dir failed:$!";
-        @file_list = list_test_files ($debian_dir);
+        dircopy( $ex_data->stringify, $destination_dir->stringify )
+          || die "dircopy $ex_data -> $destination_dir failed:$!";
+        @file_list = list_test_files ($destination_dir);
     }
     elsif ( $ex_data->exists ) {
+        # either one if true if $conf_file is undef
+        die "test data is missing \$conf_dir" unless defined $conf_dir;
+        die "test data is missing \$conf_file" unless defined $conf_file;
+
         # just copy file
         say "file copy ". $ex_data->stringify . '->'. $conf_file->stringify
             if $trace ;
@@ -98,7 +108,7 @@ sub setup_test {
     else {
         note ('starting test without original config data, i.e. from scratch');
     }
-    ok( 1, "Copied $model_test example $t_name" );
+    ok( 1, "Copied $app_to_test example $t_name" );
 
     return ( $wr_dir, $wr_dir2, $conf_file, $ex_data, @file_list );
 }
@@ -181,7 +191,7 @@ sub apply_fix {
 }
 
 sub dump_tree_full_mode {
-    my ($model_test, $root, $t, $trace) = @_;
+    my ($app_to_test, $root, $t, $trace) = @_;
 
     print "dumping tree ...\n" if $trace;
     my $dump  = '';
@@ -194,7 +204,7 @@ sub dump_tree_full_mode {
         my @tf = @{ $t->{dump_errors} };
         while (@tf) {
             my $qr = shift @tf;
-            throws_ok { &$risky } $qr, "Failed dump $nb of $model_test config tree";
+            throws_ok { &$risky } $qr, "Failed dump $nb of $app_to_test config tree";
             my $fix = shift @tf;
             $root->load($fix);
             ok( 1, "Fixed error nb " . $nb++ );
@@ -209,7 +219,7 @@ sub dump_tree_full_mode {
     else {
         warnings_like { &$risky; } $t->{dump_warnings}, "Ran dump_tree";
     }
-    ok( $dump, "Dumped $model_test config tree in full mode" );
+    ok( $dump, "Dumped $app_to_test config tree in full mode" );
 
     print $dump if $trace;
     return $dump;
@@ -308,10 +318,10 @@ sub _test_key {
 }
 
 sub write_data_back {
-    my ($model_test, $inst, $t) = @_;
+    my ($app_to_test, $inst, $t) = @_;
     local $Config::Model::Value::nowarning = $t->{no_warnings} || 0;
     $inst->write_back( force => 1 );
-    ok( 1, "$model_test write back done" );
+    ok( 1, "$app_to_test write back done" );
 }
 
 sub check_file_content {
@@ -321,9 +331,9 @@ sub check_file_content {
         foreach my $f (keys %$fc) {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
-            foreach (@tests) {
-                file_contents_eq_or_diff $wr_dir->child($f)->stringify,  $_,
-                    "check that $f contains $_";
+            foreach my $subtest (@tests) {
+                file_contents_eq_or_diff $wr_dir->child($f)->stringify,  $subtest,
+                    "check that $f contains $subtest";
             }
         }
     }
@@ -332,9 +342,9 @@ sub check_file_content {
         foreach my $f (keys %$fc) {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
-            foreach (@tests) {
-                file_contents_like $wr_dir->child($f)->stringify,  $_,
-                    "check that $f matches regexp $_";
+            foreach my $subtest (@tests) {
+                file_contents_like $wr_dir->child($f)->stringify,  $subtest,
+                    "check that $f matches regexp $subtest";
             }
         }
     }
@@ -343,9 +353,9 @@ sub check_file_content {
         foreach my $f (keys %$fc) {
             my $t = $fc->{$f} ;
             my @tests = ref $t eq 'ARRAY' ? @$t : ($t) ;
-            foreach (@tests) {
-                file_contents_unlike $wr_dir->child($f)->stringify,  $_,
-                    "check that $f does not match regexp $_";
+            foreach my $subtest (@tests) {
+                file_contents_unlike $wr_dir->child($f)->stringify,  $subtest,
+                    "check that $f does not match regexp $subtest";
             }
         }
     }
@@ -355,14 +365,18 @@ sub check_added_or_removed_files {
     my ( $conf_dir, $wr_dir, $t, @file_list) = @_;
 
     # copy whole dir
-    my $debian_dir = $conf_dir ? $wr_dir->child($conf_dir) : $wr_dir ;
-    my @new_file_list = list_test_files($debian_dir) ;
+    my $destination_dir
+        = $t->{setup} ? $wr_dir
+        : $conf_dir   ? $wr_dir->child($conf_dir)
+        :               $wr_dir ;
+    say "test dir $destination_dir";
+    my @new_file_list = list_test_files($destination_dir) ;
     $t->{file_check_sub}->( \@file_list ) if defined $t->{file_check_sub};
     eq_or_diff( \@new_file_list, [ sort @file_list ], "check added or removed files" );
 }
 
 sub create_second_instance {
-    my ($model_test, $t_name, $wr_dir, $wr_dir2,$t) = @_;
+    my ($app_to_test, $t_name, $wr_dir, $wr_dir2,$t, $config_dir_override) = @_;
 
     # create another instance to read the conf file that was just written
     dircopy( $wr_dir->stringify, $wr_dir2->stringify )
@@ -372,11 +386,13 @@ sub create_second_instance {
         root_class_name => $model_to_test,
         root_dir        => $wr_dir2->stringify,
         config_file     => $t->{config_file} ,
-        instance_name   => "$model_test-$t_name-w",
+        instance_name   => "$app_to_test-$t_name-w",
+        application     => $app_to_test,
         check           => $t->{load_check2} || 'yes',
+        config_dir      => $config_dir_override,
     );
 
-    ok( $i2_test, "Created instance $model_test-test-$t_name-w" );
+    ok( $i2_test, "Created instance $app_to_test-test-$t_name-w" );
 
     local $Config::Model::Value::nowarning = $t->{no_warnings} || 0;
     my $i2_root = $i2_test->config_root;
@@ -386,30 +402,44 @@ sub create_second_instance {
 }
 
 sub run_model_test {
-    my ($model_test, $model_test_conf, $do, $model, $trace, $wr_root) = @_ ;
+    my ($app_to_test, $app_to_test_conf, $do, $model, $trace, $wr_root) = @_ ;
 
     $skip = 0;
     undef $conf_file_name ;
     undef $conf_dir ;
     undef $home_for_test ;
 
-    note("Beginning $model_test test ($model_test_conf)");
+    note("Beginning $app_to_test test ($app_to_test_conf)");
 
-    unless ( my $return = do $model_test_conf ) {
-        warn "couldn't parse $model_test_conf: $@" if $@;
-        warn "couldn't do $model_test_conf: $!" unless defined $return;
-        warn "couldn't run $model_test_conf" unless $return;
+    unless ( my $return = do $app_to_test_conf ) {
+        warn "couldn't parse $app_to_test_conf: $@" if $@;
+        warn "couldn't do $app_to_test_conf: $!" unless defined $return;
+        warn "couldn't run $app_to_test_conf" unless $return;
     }
 
     if ($skip) {
-        note("Skipped $model_test test ($model_test_conf)");
+        note("Skipped $app_to_test test ($app_to_test_conf)");
         return;
     }
 
+    my ($trash, $appli_info, $applications) = Config::Model::Lister::available_models(1);
+
     # even undef, this resets the global variable there
     Config::Model::BackendMgr::_set_test_home($home_for_test) ;
 
-    my $note ="$model_test uses $model_to_test model";
+    if (not defined $model_to_test) {
+        $model_to_test = $applications->{$app_to_test};
+        if (not defined $model_to_test) {
+            my @k = sort values %$applications;
+            my @files = map { $_->{_file} // 'unknown' } values %$appli_info ;
+            die "Cannot find model name for $app_to_test in files >@files<. Know dev models are >@k<. ".
+                "Check your test name (the file ending with -test-conf.pl) or set the \$model_to_test global variable\n";
+        }
+    }
+
+    my $config_dir_override = $appli_info->{$app_to_test}{config_dir}; # may be undef
+
+    my $note ="$app_to_test uses $model_to_test model";
     $note .= " on file $conf_file_name" if defined $conf_file_name;
     note($note);
 
@@ -420,19 +450,21 @@ sub run_model_test {
             $idx++;
             next;
         }
-        note("Beginning subtest $model_test $t_name");
+        note("Beginning subtest $app_to_test $t_name");
 
         my ($wr_dir, $wr_dir2, $conf_file, $ex_data, @file_list)
-            = setup_test ($model_test, $t_name, $wr_root,$trace, $t->{setup});
+            = setup_test ($app_to_test, $t_name, $wr_root,$trace, $t->{setup});
 
         write_config_file($conf_dir,$wr_dir,$t);
 
         my $inst = $model->instance(
             root_class_name => $model_to_test,
             root_dir        => $wr_dir->stringify,
-            instance_name   => "$model_test-" . $t_name,
+            instance_name   => "$app_to_test-" . $t_name,
+            application     => $app_to_test,
             config_file     => $t->{config_file} ,
             check           => $t->{load_check} || 'yes',
+            config_dir      => $config_dir_override,
         );
 
         my $root = $inst->config_root;
@@ -445,9 +477,9 @@ sub run_model_test {
 
         apply_fix($inst) if  $t->{apply_fix};
 
-        dump_tree_full_mode ($model_test, $root, $t, $trace) ;
+        dump_tree_full_mode ($app_to_test, $root, $t, $trace) ;
 
-        my $dump = dump_tree_custom_mode ($model_test, $root, $t, $trace) ;
+        my $dump = dump_tree_custom_mode ($app_to_test, $root, $t, $trace) ;
 
         check_data("first", $root, $t->{check}, $t->{no_warnings}) if $t->{check};
 
@@ -456,45 +488,44 @@ sub run_model_test {
 
         check_annotation($root,$t) if $t->{verify_annotation};
 
-        write_data_back ($model_test, $inst, $t) ;
+        write_data_back ($app_to_test, $inst, $t) ;
 
         check_file_content($wr_dir,$t) ;
 
         check_added_or_removed_files ($conf_dir, $wr_dir, $t, @file_list) if $ex_data->is_dir;
 
-        my $i2_root = create_second_instance ($model_test, $t_name, $wr_dir, $wr_dir2,$t);
+        my $i2_root = create_second_instance ($app_to_test, $t_name, $wr_dir, $wr_dir2,$t, $config_dir_override);
 
-        my $p2_dump = dump_tree_custom_mode("second $model_test", $i2_root, $t) ;
+        my $p2_dump = dump_tree_custom_mode("second $app_to_test", $i2_root, $t) ;
 
         unified_diff;
         eq_or_diff(
             [ split /\n/,$p2_dump ],
             [ split /\n/,$dump ],
-            "compare original $model_test custom data with 2nd instance custom data",
+            "compare original $app_to_test custom data with 2nd instance custom data",
         );
 
         ok( -s "$wr_dir2/$conf_dir/$conf_file_name" ,
-            "check that original $model_test file was not clobbered" )
+            "check that original $app_to_test file was not clobbered" )
                 if defined $conf_file_name ;
 
         check_data("second", $i2_root, $t->{wr_check}, $t->{no_warnings}) if $t->{wr_check} ;
 
-        note("End of subtest $model_test $t_name");
+        note("End of subtest $app_to_test $t_name");
 
         $idx++;
     }
-    note("End of $model_test test");
+    note("End of $app_to_test test");
 
 }
 
 sub run_tests {
-    my ( $arg, $test_only_model, $do ) = @_;
+    my ( $arg, $test_only_app, $do ) = @_;
 
-    my ( $log, $show ) = (0) x 2;
+    my $log = 0;
 
     my $trace = ($arg =~ /t/) ? 1 : 0;
     $log  = 1 if $arg =~ /l/;
-    $show = 1 if $arg =~ /s/;
 
     my $log4perl_user_conf_file = ($ENV{HOME} || '') . '/.log4config-model';
 
@@ -520,10 +551,10 @@ sub run_tests {
 
     my @group_of_tests = grep { /-test-conf.pl$/ } glob("t/model_tests.d/*");
 
-    foreach my $model_test_conf (@group_of_tests) {
-        my ($model_test) = ( $model_test_conf =~ m!\.d/([\w\-]+)-test-conf! );
-        next if ( $test_only_model and $test_only_model ne $model_test ) ;
-        run_model_test($model_test, $model_test_conf, $do, $model, $trace, $wr_root) ;
+    foreach my $app_to_test_conf (@group_of_tests) {
+        my ($app_to_test) = ( $app_to_test_conf =~ m!\.d/([\w\-]+)-test-conf! );
+        next if ( $test_only_app and $test_only_app ne $app_to_test ) ;
+        run_model_test($app_to_test, $app_to_test_conf, $do, $model, $trace, $wr_root) ;
     }
 
     memory_cycle_ok($model,"test memory cycle") ;
@@ -545,7 +576,7 @@ Config::Model::Tester - Test framework for Config::Model
 
 =head1 VERSION
 
-version 2.052
+version 2.054
 
 =head1 SYNOPSIS
 
@@ -556,11 +587,11 @@ version 2.052
  use Config::Model::Tester ;
  use ExtUtils::testlib;
 
- my $arg = shift || '';
- my $test_only_model = shift || '';
- my $do = shift ;
+ my $arg = shift || ''; # typically e t l
+ my $test_only_app = shift || ''; # only run one set of test
+ my $do = shift ; # select subtests to run with a regexp
 
- run_tests($arg, $test_only_model, $do) ;
+ run_tests($arg, $test_only_app, $do) ;
 
 =head1 DESCRIPTION
 
@@ -568,41 +599,59 @@ This class provides a way to test configuration models with tests files.
 This class was designed to tests several models and several tests
 cases per model.
 
-A specific layout for test files must be followed
+A specific layout for test files must be followed.
 
 =head2 Simple test file layout
 
+Each test case is represented by a configuration file (not
+a directory) in the C<*-examples> directory. This configuration file
+will be used by the model to test and is copied as
+C<$confdir/$conf_file_name> using the global variables explained
+below.
+
+In the example below, we have 1 app model to test: C<lcdproc> and 2 tests
+cases. The app name matches the file specified in
+C<lib/Config/Model/*.d> directory. In this case, the app name matches
+C<lib/Config/Model/system.d/lcdproc>
+
  t
  |-- model_test.t
- \-- model_tests.d
-     |-- lcdd-test-conf.pl   # test specification
-     \-- lcdd-examples
-         |-- t0              # test case t0
-         \-- LCDD-0.5.5      # test case for older LCDproc
+ \-- model_tests.d           # do not change directory name
+     |-- lcdproc-test-conf.pl   # test specification for lcdproc app
+     \-- lcdproc-examples
+         |-- t0              # subtest t0
+         \-- LCDD-0.5.5      # subtest for older LCDproc
 
-In the example above, we have 1 model to test: C<lcdd> and 2 tests
-cases.
+Test specification is written in C<lcdproc-test-conf.pl> file (i.e. this
+modules looks for files named  like C<< <app-name>-test-conf.pl> >>).
 
-Test specification is written in C<lcdd-test-conf.pl> file. Test
-cases are plain files in C<lcdd-examples>. C<lcdd-test-conf.pl> will
-contain instructions so that each file will be used as a
-C</etc/LCDd.conf> file during each test case.
+Subtests are specified in files in directory C<lcdproc-examples> (
+i.e. this modules looks for subtests in directory
+C<< <model-name>-examples.pl> >>. C<lcdproc-test-conf.pl> contains
+instructions so that each file will be used as a C</etc/LCDd.conf>
+file during each test case.
 
-C<lcdd-test-conf.pl> can contain specifications for more test
-case. Each test case will require a new file in C<lcdd-examples>
+C<lcdproc-test-conf.pl> can contain specifications for more test
+cases. Each test case will require a new file in C<lcdproc-examples>
 directory.
 
 See L</Examples> for a link to the actual LCDproc model tests
 
 =head2 Test file layout for multi-file configuration
 
-When a configuration is spread over several files, test examples must be
-provided in sub-directories:
+When a configuration is spread over several files, each test case is
+provided in a sub-directory. This sub-directory is copied in
+C<$conf_dir> (a global variable as explained below)
+
+In the example below, the test specification is written in
+C<dpkg-test-conf.pl>. Dpkg layout requires several files per test case.
+C<dpkg-test-conf.pl> will contain instructions so that each directory
+under C<dpkg-examples> will be used.
 
  t/model_tests.d
  \-- dpkg-test-conf.pl         # test specification
  \-- dpkg-examples
-     \-- libversion            # example subdir
+     \-- libversion            # example subdir, used as subtest name
          \-- debian            # directory for one test case
              |-- changelog
              |-- compat
@@ -613,14 +662,22 @@ provided in sub-directories:
              |   \-- format
              \-- watch
 
-In the example above, the test specification is written in
-C<dpkg-test-conf.pl>. Dpkg layout requires several files per test case.
-C<dpkg-test-conf.pl> will contain instruction so that each directory
-under C<dpkg-examples> will be used.
-
 See L</Examples> for a link to the (many) Dpkg model tests
 
-=head2 Test file layout depending on system
+=head2 More complex file layout
+
+Each test case is a sub-directory on the C<*-examples> directory and
+contains several files. The destination of the test files may depend
+on the system (e.g. the OS). For instance, system wide C<ssh_config>
+is stored in C</etc/ssh> on Linux, and directly in C</etc> on MacOS.
+
+These files are copied in a test directory using a C<setup> parameter:
+
+  setup => {
+    test_file_in_example_dir => 'destination'
+  }
+
+Let's consider this example of 2 tests cases for ssh:
 
  t/model_tests.d/
  |-- ssh-test-conf.pl
@@ -629,36 +686,43 @@ See L</Examples> for a link to the (many) Dpkg model tests
          |-- system_ssh_config
          \-- user_ssh_config
 
-In this example, the layout of the configuration files depend on the
-system. For instance, system wide C<ssh_config> is stored in C</etc/ssh> on
-Linux, and directly in C</etc> on MacOS.
+Unfortunately, C<user_ssh_config> is a user file, so you specify where
+the home directory for the tests with another global variable:
 
-L<ssh-test-conf.pl|https://github.com/dod38fr/config-model-openssh/blob/master/t/model_tests.d/ssh-test-conf.pl>
-will specify the target path of each file. I.e.:
+  $home_for_test = '/home/joe' ;
 
- $home_for_test = $^O eq 'darwin' ? '/Users/joe'
-                :                   '/home/joe' ;
+For Linux only, the C<setup> parameter is:
 
- # ...
+ setup => {
+   'system_ssh_config' => '/etc/ssh/ssh_config',
+   'user_ssh_config'   => "~/.ssh/config"
+ }
+
+On the other hand, system wide config file is different on MacOS and
+the test file must be copied in the correct location. When the value
+of the C<setup> hash is another hash, the key of this other hash is
+used as to specify the target location for other OS (as returned by
+Perl C<$^O> variable:
 
       setup => {
         'system_ssh_config' => {
             'darwin' => '/etc/ssh_config',
             'default' => '/etc/ssh/ssh_config',
         },
-        'user_ssh_config' => "$home_for_test/.ssh/config"
+        'user_ssh_config' => "~/.ssh/config"
+      }
 
 See the actual L<Ssh and Sshd model tests|https://github.com/dod38fr/config-model-openssh/tree/master/t/model_tests.d>
 
 =head2 Basic test specification
 
 Each model test is specified in C<< <model>-test-conf.pl >>. This file
-contains a set of global variable. (yes, global variables are often bad ideas
+contains a set of global variables. (yes, global variables are often bad ideas
 in programs, but they are handy for tests):
 
  # config file name (used to copy test case into test wr_root directory)
  $conf_file_name = "fstab" ;
- # config dir where to copy the file
+ # config dir where to copy the file (optional)
  #$conf_dir = "etc" ;
  # home directory for this test
  $home_for_test = '/home/joe' ;
@@ -668,7 +732,7 @@ Here, C<t0> file will be copied in C<wr_root/test-t0/etc/fstab>.
  # config model name to test
  $model_to_test = "Fstab" ;
 
- # list of tests
+ # list of tests. This modules looks for @tests global variable
  @tests = (
     {
      # test name
@@ -678,23 +742,24 @@ Here, C<t0> file will be copied in C<wr_root/test-t0/etc/fstab>.
     {
      name => 't1',
      # add optional specification here for t1 test
-     },
+    },
  );
 
  1; # to keep Perl happy
 
 You can suppress warnings by specifying C<< no_warnings => 1 >>. On
-the other hand, you may also want to check for warnings specifid to
+the other hand, you may also want to check for warnings specified to
 your model. In this case, you should avoid specifying C<no_warnings>
-here and use the more specify warning tests or warning filters
-mentioned below.
+here and specify warning tests or warning filters as mentioned below.
 
 See actual L<fstab test|https://github.com/dod38fr/config-model/blob/master/t/model_tests.d/fstab-test-conf.pl>.
 
-=head2 Internal tests
+=head2 Internal tests or backend tests
 
 Some tests will require the creation of a configuration class dedicated
-for test. This test class can be created directly in the test specification
+for test (typically to test corner cases on a backend).
+
+This test class can be created directly in the test specification
 by calling L<create_config_class|Config::Model/create_config_class> on
 C<$model> variable. See for instance the
 L<layer test|https://github.com/dod38fr/config-model/blob/master/t/model_tests.d/layer-test-conf.pl>
@@ -721,22 +786,16 @@ See actual L<multistrap test|https://github.com/dod38fr/config-model/blob/master
 =head2 Test scenario
 
 Each subtest follow a sequence explained below. Each step of this
-sequence may be altered by adding specification in the test case:
+sequence may be altered by adding specification in
+C<< <model-to-test>-test-conf.pl >>:
 
 =over
 
 =item *
 
 Setup test in C<< wr_root/<subtest name>/ >>. If your configuration file layout depend
-on the target system, you will have to specify the path using C<setup> parameter:
-
- setup => {
-    'file_name_in_examples_dir' => {
-        'darwin' => '/etc/foo', # macosx
-        'default' => '/etc/bar' # others
-    },
-    'another_file_in_examples_dir' => $computed_path
- }
+on the target system, you will have to specify the path using C<setup> parameter.
+See L</"Test file layout depending on system">.
 
 =item *
 
@@ -750,7 +809,7 @@ E.g.
 
     load_warnings => [ qr/Missing/, (qr/deprecated/) x 3 , ],
 
-Use an empty array_ref to masks load warnings.
+Use an empty array_ref to mask load warnings.
 
 =item *
 
@@ -769,6 +828,8 @@ suppress any error or warning mentioned above. E.g:
 
     load => 'binary:seaview Synopsis="multiplatform interface for sequence alignment"',
 
+See L<Config::Model::Loader> for the syntax of the string accepted by C<load> parameter.
+
 =item *
 
 Optionally, call L<apply_fixes|Config::Model::Instance/apply_fixes>:
@@ -801,29 +862,32 @@ You can tolerate any dump warning this way:
 Run specific content check to verify that configuration data was retrieved
 correctly:
 
-    check => [
+    check => {
         'fs:/proc fs_spec',           "proc" ,
         'fs:/proc fs_file',           "/proc" ,
         'fs:/home fs_file',          "/home",
-    ],
+    },
+
+The keys of the hash points to the value to be checked using the
+syntax described in L<Config::Model::AnyThing:/"grab(...)">.
 
 You can run check using different check modes (See L<Config::Model::Value/"fetch( ... )">)
 by passing a hash ref instead of a scalar :
 
-    check  => [
-        'sections:debian packages:0' , { qw/mode layered value dpkg-dev/},
-        'sections:base packages:0',    { qw/mode layered value gcc-4.2-base/},
-    ],
+    check  => {
+        'sections:debian packages:0' , { mode => 'layered', value => 'dpkg-dev' },
+        'sections:base packages:0',    { mode => 'layered', value => "gcc-4.2-base' },
+    },
 
 The whole hash content (except "value") is passed to  L<grab|Config::Model::AnyThing/"grab(...)">
 and L<fetch|Config::Model::Value/"fetch( ... )">
 
 A regexp can also be used to check value:
 
-   check => [
+   check => {
       "License text" => qr/gnu/i,
       "License text" => { mode => 'custom', value => qr/gnu/i },
-   ]
+   }
 
 =item *
 
@@ -890,7 +954,7 @@ specify a subref to alter the file list:
         my $list_ref = shift ;
         # file added during tests
         push @$list_ref, "/debian/source/format" ;
-    };
+    },
 
 =item *
 
@@ -919,9 +983,9 @@ Run specific content check on the B<written> config file to verify that
 configuration data was written and retrieved correctly:
 
     wr_check => {
-        'fs:/proc fs_spec',           "proc" ,
-        'fs:/proc fs_file',           "/proc" ,
-        'fs:/home fs_file',          "/home",
+        'fs:/proc fs_spec' =>          "proc" ,
+        'fs:/proc fs_file' =>          "/proc",
+        'fs:/home fs_file' =>          "/home",
     },
 
 Like the C<check> item explained above, you can run C<wr_check> using
@@ -929,11 +993,12 @@ different check modes.
 
 =back
 
-=head2 running the test
+=head2 Running the test
 
-Run all tests:
+Run all tests with one of these commands:
 
- prove -l t/model_test.t
+ prove -l t/model_test.t :: [ t|l|e [ <model_name> [ <regexp> ]]]
+ perl -Ilib t/model_test.t  [ t|l|e [ <model_name> [ <regexp> ]]]
 
 By default, all tests are run on all models.
 
@@ -1022,7 +1087,7 @@ Dominique Dumont
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Dominique Dumont.
+This software is Copyright (c) 2013-2016 by Dominique Dumont.
 
 This is free software, licensed under:
 
@@ -1041,14 +1106,6 @@ in addition to those websites please use your favorite search engine to discover
 
 =item *
 
-MetaCPAN
-
-A modern, open-source CPAN search engine, useful to view POD in HTML format.
-
-L<http://metacpan.org/release/Config-Model-Tester>
-
-=item *
-
 Search CPAN
 
 The default CPAN search engine, useful to view POD in HTML format.
@@ -1057,14 +1114,6 @@ L<http://search.cpan.org/dist/Config-Model-Tester>
 
 =item *
 
-RT: CPAN's Bug Tracker
-
-The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Config-Model-Tester>
-
-=item *
-
 AnnoCPAN
 
 The AnnoCPAN is a website that allows community annotations of Perl module documentation.
@@ -1081,14 +1130,6 @@ L<http://cpanratings.perl.org/d/Config-Model-Tester>
 
 =item *
 
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Config-Model-Tester>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -1123,8 +1164,8 @@ L<http://deps.cpantesters.org/?module=Config::Model::Tester>
 
 =head2 Bugs / Feature Requests
 
-Please report any bugs or feature requests by email to C<bug-config-model-tester at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Config-Model-Tester>. You will be automatically notified of any
+Please report any bugs or feature requests by email to C<ddumont at cpan.org>, or through
+the web interface at L<https://github.com/dod38fr/config-model-tester/issues>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
